@@ -1,18 +1,7 @@
 /*
- * Copyright 2016-2017 Matthieu Gallien <matthieu_gallien@yahoo.fr>
- *
- * This program is free software: you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-FileCopyrightText: 2016 (c) Matthieu Gallien <matthieu_gallien@yahoo.fr>
+
+   SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
 #ifndef DATABASEINTERFACE_H
@@ -83,6 +72,10 @@ public:
 
     DataTypes::ListArtistDataType allArtistsDataByGenre(const QString &genre);
 
+    DataTypes::ArtistDataType artistDataFromDatabaseId(qulonglong id);
+
+    qulonglong artistIdFromName(const QString &name);
+
     DataTypes::ListGenreDataType allGenresData();
 
     bool internalArtistMatchGenre(qulonglong databaseId, const QString &genre);
@@ -266,6 +259,8 @@ private:
 
     DataTypes::AlbumDataType internalOneAlbumPartialData(qulonglong databaseId);
 
+    DataTypes::ArtistDataType internalOneArtistPartialData(qulonglong databaseId);
+
     DataTypes::ListTrackDataType internalAllTracksPartialData();
 
     DataTypes::ListRadioDataType internalAllRadiosPartialData();
