@@ -1,19 +1,8 @@
 /*
- * Copyright 2016-2017 Matthieu Gallien <matthieu_gallien@yahoo.fr>
- * Copyright 2019 Alexander Stippich <a.stippich@gmx.net>
- *
- * This program is free software: you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-FileCopyrightText: 2016 (c) Matthieu Gallien <matthieu_gallien@yahoo.fr>
+   SPDX-FileCopyrightText: 2019 (c) Alexander Stippich <a.stippich@gmx.net>
+
+   SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
 #ifndef DATATYPES_H
@@ -21,6 +10,8 @@
 
 #include "elisaLib_export.h"
 
+#include "elisautils.h"
+
 #include <QObject>
 #include <QString>
 #include <QList>
@@ -76,35 +67,63 @@ public:
         PlayFrequency,
         ElementTypeRole,
         LyricsRole,
+        FullDataRole,
+        IsDirectoryRole,
+        IsPlayListRole,
+        FilePathRole,
     };
 
     Q_ENUM(ColumnsRoles)
 
-private:
-
     using DataType = QMap<ColumnsRoles, QVariant>;
 
 public:
 
-    class TrackDataType : public DataType
+    class MusicDataType : public DataType
+    {
+    public:
+        using DataType::DataType;
+
+        bool hasDatabaseId() const
+        {
+            return find(key_type::DatabaseIdRole) != end();
+        }
+
+        qulonglong databaseId() const
+        {
+            return operator[](key_type::DatabaseIdRole).toULongLong();
+        }
+
+        bool hasElementType() const
+        {
+            return find(key_type::ElementTypeRole) != end();
+        }
+
+        ElisaUtils::PlayListEntryType elementType() const
+        {
+            return operator[](key_type::ElementTypeRole).value<ElisaUtils::PlayListEntryType>();
+        }
+    };
+
+    class TrackDataType : public MusicDataType
     {
     public:
 
-        using DataType::DataType;
+        using MusicDataType::MusicDataType;
 
         TrackDataType(bool aValid, QString aId, QString aParentId, QString aTitle, QString aArtist, QString aAlbumName,
                       QString aAlbumArtist, int aTrackNumber, int aDiscNumber, QTime aDuration, QUrl aResourceURI,
                       const QDateTime &fileModificationTime, QUrl aAlbumCover, int rating, bool aIsSingleDiscAlbum,
                       QString aGenre, QString aComposer, QString aLyricist, bool aHasEmbeddedCover)
-            : DataType({{key_type::TitleRole, std::move(aTitle)}, {key_type::AlbumRole, std::move(aAlbumName)},
-                        {key_type::ArtistRole, std::move(aArtist)}, {key_type::AlbumArtistRole, std::move(aAlbumArtist)},
-                        {key_type::IdRole, std::move(aId)}, {key_type::ParentIdRole, std::move(aParentId)},
-                        {key_type::TrackNumberRole, aTrackNumber}, {key_type::DiscNumberRole, aDiscNumber},
-                        {key_type::DurationRole, aDuration}, {key_type::ResourceRole, std::move(aResourceURI)},
-                        {key_type::FileModificationTime, fileModificationTime}, {key_type::ImageUrlRole, std::move(aAlbumCover)},
-                        {key_type::RatingRole, rating}, {key_type::IsSingleDiscAlbumRole, aIsSingleDiscAlbum},
-                        {key_type::GenreRole, std::move(aGenre)}, {key_type::ComposerRole, std::move(aComposer)},
-                        {key_type::LyricistRole, std::move(aLyricist)}, {key_type::HasEmbeddedCover, aHasEmbeddedCover},})
+            : MusicDataType({{key_type::TitleRole, std::move(aTitle)}, {key_type::AlbumRole, std::move(aAlbumName)},
+                             {key_type::ArtistRole, std::move(aArtist)}, {key_type::AlbumArtistRole, std::move(aAlbumArtist)},
+                             {key_type::IdRole, std::move(aId)}, {key_type::ParentIdRole, std::move(aParentId)},
+                             {key_type::TrackNumberRole, aTrackNumber}, {key_type::DiscNumberRole, aDiscNumber},
+                             {key_type::DurationRole, aDuration}, {key_type::ResourceRole, std::move(aResourceURI)},
+                             {key_type::FileModificationTime, fileModificationTime}, {key_type::ImageUrlRole, std::move(aAlbumCover)},
+                             {key_type::RatingRole, rating}, {key_type::IsSingleDiscAlbumRole, aIsSingleDiscAlbum},
+                             {key_type::GenreRole, std::move(aGenre)}, {key_type::ComposerRole, std::move(aComposer)},
+                             {key_type::LyricistRole, std::move(aLyricist)}, {key_type::HasEmbeddedCover, aHasEmbeddedCover},})
         {
             Q_UNUSED(aValid)
         }
@@ -114,11 +133,6 @@ public:
             return !isEmpty() && duration().isValid();
         }
 
-        qulonglong databaseId() const
-        {
-            return operator[](key_type::DatabaseIdRole).toULongLong();
-        }
-
         QString title() const
         {
             return operator[](key_type::TitleRole).toString();
@@ -275,16 +289,11 @@ public:
 
     using ListRadioDataType = QList<TrackDataType>;
 
-    class AlbumDataType : public DataType
+    class AlbumDataType : public MusicDataType
     {
     public:
 
-        using DataType::DataType;
-
-        qulonglong databaseId() const
-        {
-            return operator[](key_type::DatabaseIdRole).toULongLong();
-        }
+        using MusicDataType::MusicDataType;
 
         QString title() const
         {
@@ -326,11 +335,16 @@ public:
 
     using ListAlbumDataType = QList<AlbumDataType>;
 
-    class ArtistDataType : public DataType
+    class ArtistDataType : public MusicDataType
     {
     public:
 
-        using DataType::DataType;
+        using MusicDataType::MusicDataType;
+
+        QString name() const
+        {
+            return operator[](key_type::TitleRole).toString();
+        }
 
         qulonglong databaseId() const
         {
@@ -341,16 +355,11 @@ public:
 
     using ListArtistDataType = QList<ArtistDataType>;
 
-    class GenreDataType : public DataType
+    class GenreDataType : public MusicDataType
     {
     public:
 
-        using DataType::DataType;
-
-        qulonglong databaseId() const
-        {
-            return operator[](key_type::DatabaseIdRole).toULongLong();
-        }
+        using MusicDataType::MusicDataType;
 
         QString title() const
         {
@@ -361,8 +370,12 @@ public:
 
     using ListGenreDataType = QList<GenreDataType>;
 
+    using EntryData = std::tuple<MusicDataType, QString, QUrl>;
+    using EntryDataList = QList<EntryData>;
+
 };
 
+Q_DECLARE_METATYPE(DataTypes::MusicDataType)
 Q_DECLARE_METATYPE(DataTypes::TrackDataType)
 Q_DECLARE_METATYPE(DataTypes::AlbumDataType)
 Q_DECLARE_METATYPE(DataTypes::ArtistDataType)
@@ -373,4 +386,7 @@ Q_DECLARE_METATYPE(DataTypes::ListAlbumDataType)
 Q_DECLARE_METATYPE(DataTypes::ListArtistDataType)
 Q_DECLARE_METATYPE(DataTypes::ListGenreDataType)
 
+Q_DECLARE_METATYPE(DataTypes::EntryData)
+Q_DECLARE_METATYPE(DataTypes::EntryDataList)
+
 #endif // DATATYPES_H
