@@ -1,18 +1,7 @@
 /*
- * Copyright 2018 Matthieu Gallien <matthieu_gallien@yahoo.fr>
- *
- * This program is free software: you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-FileCopyrightText: 2018 (c) Matthieu Gallien <matthieu_gallien@yahoo.fr>
+
+   SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
 #include "filescanner.h"
@@ -211,9 +200,6 @@ void FileScanner::scanProperties(const QString &localFileName, DataTypes::TrackD
             value = QLocale().createSeparatedList(list);
         } else {
             value = (*rangeBegin).second;
-            if (value.canConvert<QStringList>()) {
-                value = QLocale().createSeparatedList(value.toStringList());
-            }
         }
         const auto &translatedKey = d->propertyTranslation.find(key);
         if (translatedKey.value() == DataTypes::DurationRole) {
