@@ -1,18 +1,7 @@
 /*
- * Copyright 2015-2017 Matthieu Gallien <matthieu_gallien@yahoo.fr>
- *
- * This program is free software: you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-FileCopyrightText: 2015 (c) Matthieu Gallien <matthieu_gallien@yahoo.fr>
+
+   SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
 #include "mediaplaylist.h"
@@ -113,7 +102,7 @@ QVariant MediaPlayList::data(const QModelIndex &index, int role) const
             result = d->mData[index.row()].mIsPlaying;
             break;
         case ColumnsRoles::ElementTypeRole:
-            result = d->mData[index.row()].mEntryType;
+            result = QVariant::fromValue(d->mData[index.row()].mEntryType);
             break;
         case ColumnsRoles::StringDurationRole:
         {
@@ -346,94 +335,98 @@ void MediaPlayList::enqueueRestoredEntries(const QVariantList &newEntries)
     endInsertRows();
 }
 
-void MediaPlayList::enqueueFilesList(const ElisaUtils::EntryDataList &newEntries, ElisaUtils::PlayListEntryType databaseIdType)
+void MediaPlayList::enqueueFilesList(const DataTypes::EntryDataList &newEntries)
 {
     qCDebug(orgKdeElisaPlayList()) << "MediaPlayList::enqueueFilesList";
 
     beginInsertRows(QModelIndex(), d->mData.size(), d->mData.size() + newEntries.size() - 1);
     for (const auto &oneTrackUrl : newEntries) {
-        switch (databaseIdType)
-        {
-        case ElisaUtils::Radio:
-        case ElisaUtils::Track:
-        case ElisaUtils::FileName:
-        {
-            const auto &trackUrl = std::get<2>(oneTrackUrl);
-            auto newEntry = MediaPlayListEntry(trackUrl);
-            newEntry.mEntryType = databaseIdType;
-            d->mData.push_back(newEntry);
-            if (trackUrl.isValid()) {
-                if (trackUrl.isLocalFile()) {
-                    d->mTrackData.push_back({{DataTypes::ColumnsRoles::ResourceRole, trackUrl}});
-                    auto entryString =  trackUrl.toLocalFile();
-                    QFileInfo newTrackFile(entryString);
-                    if (newTrackFile.exists()) {
-                        d->mData.last().mIsValid = true;
-                    }
-                } else {
-                    d->mTrackData.push_back({{DataTypes::ColumnsRoles::ResourceRole, trackUrl},
-                                             {DataTypes::ColumnsRoles::TitleRole, trackUrl.fileName()}});
+        const auto &trackUrl = std::get<2>(oneTrackUrl);
+        auto newEntry = MediaPlayListEntry(trackUrl);
+        newEntry.mEntryType = ElisaUtils::FileName;
+        d->mData.push_back(newEntry);
+        if (trackUrl.isValid()) {
+            if (trackUrl.isLocalFile()) {
+                d->mTrackData.push_back({{DataTypes::ColumnsRoles::ResourceRole, trackUrl}});
+                auto entryString =  trackUrl.toLocalFile();
+                QFileInfo newTrackFile(entryString);
+                if (newTrackFile.exists()) {
                     d->mData.last().mIsValid = true;
                 }
-                Q_EMIT newUrlInList(trackUrl, newEntry.mEntryType);
             } else {
+                d->mTrackData.push_back({{DataTypes::ColumnsRoles::ResourceRole, trackUrl},
+                                         {DataTypes::ColumnsRoles::TitleRole, trackUrl.fileName()}});
+                d->mData.last().mIsValid = true;
+            }
+            Q_EMIT newUrlInList(trackUrl, newEntry.mEntryType);
+        } else {
+            d->mTrackData.push_back({});
+        }
+    }
+    endInsertRows();
+}
+
+void MediaPlayList::enqueueOneEntry(const DataTypes::EntryData &entryData)
+{
+    if (!std::get<0>(entryData).isEmpty() || !std::get<1>(entryData).isEmpty() || !std::get<2>(entryData).isEmpty()) {
+        beginInsertRows(QModelIndex(), d->mData.size(), d->mData.size());
+        if (!std::get<0>(entryData).databaseId() && std::get<2>(entryData).isValid()) {
+            auto newEntry = MediaPlayListEntry{std::get<2>(entryData)};
+            newEntry.mEntryType = ElisaUtils::FileName;
+            d->mData.push_back(std::move(newEntry));
+            d->mTrackData.push_back({});
+        } else {
+            qCDebug(orgKdeElisaPlayList()) << "MediaPlayList::enqueueOneEntry" << std::get<0>(entryData) << std::get<1>(entryData) << std::get<0>(entryData).elementType();
+
+            d->mData.push_back(MediaPlayListEntry{std::get<0>(entryData).databaseId(), std::get<1>(entryData), std::get<0>(entryData).elementType()});
+            const auto &data = std::get<0>(entryData);
+            switch (data.elementType())
+            {
+            case ElisaUtils::Track:
+            case ElisaUtils::Radio:
+                d->mTrackData.push_back(static_cast<const DataTypes::TrackDataType&>(data));
+                break;
+            default:
                 d->mTrackData.push_back({});
             }
-            break;
         }
-        case ElisaUtils::Album:
-        case ElisaUtils::Artist:
-        case ElisaUtils::Genre:
-        case ElisaUtils::Lyricist:
-        case ElisaUtils::Composer:
-        case ElisaUtils::Unknown:
-            break;
+        if (std::get<2>(entryData).isValid()) {
+            Q_EMIT newUrlInList(std::get<2>(entryData), std::get<0>(entryData).elementType());
+        } else {
+            Q_EMIT newEntryInList(std::get<0>(entryData).databaseId(), std::get<1>(entryData), std::get<0>(entryData).elementType());
         }
-    }
-    endInsertRows();
-}
-
-void MediaPlayList::enqueueTracksListById(const ElisaUtils::EntryDataList &newEntries, ElisaUtils::PlayListEntryType type)
-{
-    qCDebug(orgKdeElisaPlayList()) << "MediaPlayList::enqueueTracksListById" << newEntries.size() << type;
-
-    beginInsertRows(QModelIndex(), d->mData.size(), d->mData.size() + newEntries.size() - 1);
-    for (const auto &newTrack : newEntries) {
-        auto newMediaPlayListEntry = MediaPlayListEntry{std::get<0>(newTrack).databaseId(), std::get<1>(newTrack), type};
-        d->mData.push_back(newMediaPlayListEntry);
-        d->mTrackData.push_back(std::get<0>(newTrack));
-        Q_EMIT newEntryInList(newMediaPlayListEntry.mId, newMediaPlayListEntry.mTitle.toString(), newMediaPlayListEntry.mEntryType);
-    }
-    endInsertRows();
-}
-
-void MediaPlayList::enqueueOneEntry(const ElisaUtils::EntryData &entryData, ElisaUtils::PlayListEntryType type)
-{
-    qCDebug(orgKdeElisaPlayList()) << "MediaPlayList::enqueueOneEntry" << std::get<0>(entryData) << std::get<1>(entryData) << type;
-
-    if (!std::get<0>(entryData).isEmpty() || !std::get<1>(entryData).isEmpty()) {
-        beginInsertRows(QModelIndex(), d->mData.size(), d->mData.size());
-        d->mData.push_back(MediaPlayListEntry{std::get<0>(entryData).databaseId(), std::get<1>(entryData), type});
-        d->mTrackData.push_back(std::get<0>(entryData));
-        Q_EMIT newEntryInList(std::get<0>(entryData).databaseId(), std::get<1>(entryData), type);
         endInsertRows();
     }
 }
 
-void MediaPlayList::enqueueMultipleEntries(const ElisaUtils::EntryDataList &entriesData, ElisaUtils::PlayListEntryType type)
+void MediaPlayList::enqueueMultipleEntries(const DataTypes::EntryDataList &entriesData)
 {
-    qCDebug(orgKdeElisaPlayList()) << "MediaPlayList::enqueueMultipleEntries" << entriesData.size() << type;
+    qCDebug(orgKdeElisaPlayList()) << "MediaPlayList::enqueueMultipleEntries" << entriesData.size();
 
     beginInsertRows(QModelIndex(), d->mData.size(), d->mData.size() + entriesData.size() - 1);
     for (const auto &entryData : entriesData) {
         if (!std::get<0>(entryData).databaseId() && std::get<2>(entryData).isValid()) {
-            d->mData.push_back(MediaPlayListEntry{std::get<2>(entryData)});
+            auto newEntry = MediaPlayListEntry{std::get<2>(entryData)};
+            newEntry.mEntryType = ElisaUtils::FileName;
+            d->mData.push_back(std::move(newEntry));
             d->mTrackData.push_back({});
-            Q_EMIT newUrlInList(std::get<2>(entryData), type);
         } else {
-            d->mData.push_back(MediaPlayListEntry{std::get<0>(entryData).databaseId(), std::get<1>(entryData), type});
-            d->mTrackData.push_back(std::get<0>(entryData));
-            Q_EMIT newEntryInList(std::get<0>(entryData).databaseId(), std::get<1>(entryData), type);
+            d->mData.push_back(MediaPlayListEntry{std::get<0>(entryData).databaseId(), std::get<1>(entryData), std::get<0>(entryData).elementType()});
+            const auto &data = std::get<0>(entryData);
+            switch (data.elementType())
+            {
+            case ElisaUtils::Track:
+            case ElisaUtils::Radio:
+                d->mTrackData.push_back(static_cast<const DataTypes::TrackDataType&>(data));
+                break;
+            default:
+                d->mTrackData.push_back({});
+            }
+        }
+        if (std::get<2>(entryData).isValid()) {
+            Q_EMIT newUrlInList(std::get<2>(entryData), std::get<0>(entryData).elementType());
+        } else {
+            Q_EMIT newEntryInList(std::get<0>(entryData).databaseId(), std::get<1>(entryData), std::get<0>(entryData).elementType());
         }
     }
     endInsertRows();
