@@ -1,19 +1,8 @@
 /*
- * Copyright 2015-2017 Matthieu Gallien <matthieu_gallien@yahoo.fr>
- * Copyright 2019-2020 Alexander Stippich <a.stippich@gmx.net>
- *
- * This program is free software: you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-FileCopyrightText: 2015 (c) Matthieu Gallien <matthieu_gallien@yahoo.fr>
+   SPDX-FileCopyrightText: 2019 (c) Alexander Stippich <a.stippich@gmx.net>
+
+   SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
 #ifndef MEDIAPLAYLISTPROXYMODEL_H
@@ -21,6 +10,7 @@
 
 #include "elisaLib_export.h"
 #include "elisautils.h"
+#include "datatypes.h"
 
 #include <QAbstractProxyModel>
 #include <QMediaPlayer>
@@ -124,33 +114,22 @@ public:
 
 public Q_SLOTS:
 
-    void enqueue(const ElisaUtils::EntryData &newEntry, ElisaUtils::PlayListEntryType databaseIdType);
-
-    void enqueue(const ElisaUtils::EntryDataList &newEntries, ElisaUtils::PlayListEntryType databaseIdType);
-
-    void enqueue(qulonglong newEntryDatabaseId, const QString &newEntryTitle,
-                 ElisaUtils::PlayListEntryType databaseIdType,
-                 ElisaUtils::PlayListEnqueueMode enqueueMode,
-                 ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay);
-
     void enqueue(const QUrl &entryUrl,
-                 ElisaUtils::PlayListEntryType databaseIdType,
                  ElisaUtils::PlayListEnqueueMode enqueueMode,
                  ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay);
 
-    void enqueue(const ElisaUtils::EntryData &newEntry,
-                 ElisaUtils::PlayListEntryType databaseIdType,
+    void enqueue(const DataTypes::MusicDataType &newEntry,
+                 const QString &newEntryTitle,
                  ElisaUtils::PlayListEnqueueMode enqueueMode,
                  ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay);
 
-    void enqueue(const ElisaUtils::EntryDataList &newEntries,
-                 ElisaUtils::PlayListEntryType databaseIdType,
+    void enqueue(const DataTypes::EntryDataList &newEntries,
                  ElisaUtils::PlayListEnqueueMode enqueueMode,
                  ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay);
 
-    void setRepeatPlay(const bool value);
+    void setRepeatPlay(bool value);
 
-    void setShufflePlayList(const bool value);
+    void setShufflePlayList(bool value);
 
     void trackInError(const QUrl &sourceInError, QMediaPlayer::Error playerError);
 
@@ -176,6 +155,11 @@ public Q_SLOTS:
 
     void setPersistentState(const QVariantMap &persistentState);
 
+    void enqueueDirectory(const QUrl &fileName,
+                          ElisaUtils::PlayListEntryType databaseIdType,
+                          ElisaUtils::PlayListEnqueueMode enqueueMode,
+                          ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay, int depth);
+
 Q_SIGNALS:
 
     void previousTrackChanged(const QPersistentModelIndex &previousTrack);
